@@ -10,7 +10,7 @@ import warnings
 import instancelib
 from numpy.linalg import LinAlgError
 from numba.experimental import jitclass
-from numba import jit, types, typed, int32, prange
+from numba import jit, types, typed, int32, prange # type: ignore
 from numba.typed import List as NumbaList
 import pandas as pd
 
